@@ -43,7 +43,11 @@ class UpdateBulkListSerializer(serializers.ListSerializer):
                 instance.modified = modified
 
         try:
-            self.child.Meta.model.objects.bulk_update(instances, writable_fields)
+            if getattr(self.child.Meta, "model_save", False):
+                for instance in instances:
+                    instance.save(update_fields=writable_fields)
+            else:
+                self.child.Meta.model.objects.bulk_update(instances, writable_fields)
         except IntegrityError as e:
             raise ValidationError(e)
 
